[include badges]
<img style="float: right;" src="mlduct/utils/_images/logo.png" width="170" height="120" align="right">
# ML - Duct : A pipeline Framework
<ins>A personal package for Machine Learning Pipelines</ins>
****

## <ins>Usage</ins>

A machine learning framework, to incorporate from data processing to modelling.
PS: Inspired from Keras

```py
# Imports


```